@@ -41,23 +41,10 @@ def expected_failure(test):
     return inner
 
 
-def expected_failure_travisci(test):
-    """Like expected_failure, but only expects a failure when the
-    env-var TRAVIS is "true"
-    """
-
-    @functools.wraps(test)
-    def inner(*args, **kwargs):
-        if os.getenv("TRAVIS", "false") == "true":
-            try:
-                test(*args, **kwargs)
-            except AssertionError:
-                from nose.plugins.skip import SkipTest
-                raise SkipTest("Expected failure failed, as expected on Travis-CI")
-            else:
-                raise AssertionError('Failure expected on Travis-CI')
-
-        else:
-            return test(*args, **kwargs)
-
-    return inner
+def attr(name):
+    try:
+        from nosetest.attrib import attr as _a
+        return _a(name)
+    except ImportError:
+        import pytest
+        return getattr(pytest.mark, name)
