@@ -71,23 +71,23 @@ files['s01e01_format'] = [
     'seasonnumber': 2, 'episodenumbers': [2],
     'episodenames': ['The One Where They Build a House']},
 
-    {'input': 'Horizon - s2008e02 - Total Isolation.avi',
-    'parsedseriesname': 'Horizon',
-    'correctedseriesname': 'Horizon',
-    'seasonnumber': 2008, 'episodenumbers': [2],
-    'episodenames': ['Total Isolation']},
+    {'input': 'Next Stop Discovery - s2001e02 - Arkawa line.avi',
+    'parsedseriesname': 'Next Stop Discovery',
+    'correctedseriesname': 'Next Stop Discovery',
+    'seasonnumber': 2001, 'episodenumbers': [2],
+    'episodenames': ['Arakawa line']},
 
-    {'input': 'Horizon.s2008e02.Total Isolation.avi',
-    'parsedseriesname': 'Horizon',
-    'correctedseriesname': 'Horizon',
-    'seasonnumber': 2008, 'episodenumbers': [2],
-    'episodenames': ['Total Isolation']},
+    {'input': 'next.stop.discovery.s2001e02.arkawa.line.avi',
+    'parsedseriesname': 'next stop discovery',
+    'correctedseriesname': 'Next Stop Discovery',
+    'seasonnumber': 2001, 'episodenumbers': [2],
+    'episodenames': ['Arakawa line']},
 
-    {'input': 'Horizon - [2008x03] - Total Isolation.avi',
-    'parsedseriesname': 'Horizon',
-    'correctedseriesname': 'Horizon',
-    'seasonnumber': 2008, 'episodenumbers': [3],
-    'episodenames': ['What on Earth is Wrong With Gravity?']},
+    {'input': 'next stop discovery - [2001x03] - Total Isolation.avi',
+    'parsedseriesname': 'next stop discovery',
+    'correctedseriesname': 'Next Stop Discovery',
+    'seasonnumber': 2001, 'episodenumbers': [3],
+    'episodenames': ['Spring winds in the Bay City']},
 
     {'input': 'Scrubs.0101.avi',
     'parsedseriesname': 'Scrubs',
@@ -151,11 +151,11 @@ files['misc'] = [
     'seasonnumber': 1, 'episodenumbers': [1],
     'episodenames': ['Episode #1']},
 
-    {'input': 'Neighbours - Episode 5824 [S 6 - Ep 003] - Fri 15 Jan 2010 [KCRT].avi',
-    'parsedseriesname': 'Neighbours',
-    'correctedseriesname': 'Neighbours',
-    'seasonnumber': 6, 'episodenumbers': [3],
-    'episodenames': ['Episode 1350']},
+    {'input': 'Scrubs - Episode 2 [S 1 - Ep 002] - Fri 24 Jan 2001 [KCRT].avi',
+    'parsedseriesname': 'Scrubs',
+    'correctedseriesname': 'Scrubs',
+    'seasonnumber': 1, 'episodenumbers': [2],
+    'episodenames': ['My Mentor']},
 
     {'input': 'Scrubs Season 01 Episode 01 - The Series Title.avi',
     'parsedseriesname': 'Scrubs',
@@ -282,12 +282,6 @@ files['unicode'] = [
     'seasonnumber': 1, 'episodenumbers': [11],
     'episodenames': ['The Day of the Dead']},
 
-    {'input': u'T\xecnh Ng\u01b0\u1eddi Hi\u1ec7n \u0110\u1ea1i - [01x01]',
-    'parsedseriesname': u'T\xecnh Ng\u01b0\u1eddi Hi\u1ec7n \u0110\u1ea1i',
-    'correctedseriesname': u'Virtues Of Harmony II',
-    'seasonnumber': 1, 'episodenumbers': [1],
-    'episodenames': [u'T\xecnh Ng\u01b0\u1eddi Hi\u1ec7n \u0110\u1ea1i - Virtues Of Harmony II']},
-
     {'input': u'The Big Bang Theory - S02E07 - The Panty Pi\xf1ata Polarization.avi',
     'parsedseriesname': u'The Big Bang Theory',
     'correctedseriesname': u'The Big Bang Theory',
@@ -334,7 +328,7 @@ files['anime'] = [
 
     {'input': '[Shinsen-Subs] True Mazinger - 07 [848x480 H.264 Vorbis][787D0074].mkv',
     'parsedseriesname': 'True Mazinger',
-    'correctedseriesname': 'True Mazinger: Shocking! Z Chapter',
+    'correctedseriesname': 'Mazinger Edition Z: The Impact!',
     'seasonnumber': None, 'episodenumbers': [7],
     'episodenames': ['Legend! The Mechanical Beasts of Bardos!']},
 
