@@ -3,10 +3,12 @@
 """Test tvnamer's EpisodeInfo file name generation
 """
 
+import os
 import datetime
 
 from helpers import assertEquals
 
+from tvnamer.compat import PY2
 from tvnamer.utils import (EpisodeInfo, DatedEpisodeInfo, NoSeasonEpisodeInfo)
 from test_files import files
 
@@ -40,14 +42,19 @@ def verify_name_gen(curtest, tvdb_instance):
 def test_name_generation_on_testfiles():
     # Test data stores episode names in English, language= is normally set
     # via the configuration, same with search_all_languages.
-    tvdb_instance = Tvdb(search_all_languages=True, language='en')
-    for category, testcases in files.items():
-        for testindex, curtest in enumerate(testcases):
-            cur_tester = lambda x: verify_name_gen(x, tvdb_instance)
-            cur_tester.description = 'test_name_generation_%s_%d: %r' % (
-                category, testindex, curtest['input'])
-            yield (cur_tester, curtest)
 
+    if not PY2 and os.getenv("TRAVIS", "false") == "true":
+        # Disable caching on Travis-CI because in Python 3 it errors with:
+        #
+        # Can't pickle <class 'http.cookiejar.DefaultCookiePolicy'>: it's not the same object as http.cookiejar.DefaultCookiePolicy
+        cache = False
+    else:
+        cache = True
+
+    tvdb_instance = Tvdb(search_all_languages=True, language='en', cache=cache)
+    for category, testcases in files.items():
+        for curtest in testcases:
+            verify_name_gen(curtest, tvdb_instance)
 
 def test_single_episode():
     """Simple episode name, with show/season/episode/name/filename
@@ -86,7 +93,7 @@ def test_episode_numeric_title():
     """An episode with a name starting with a number should not be
     detected as a range
     """
-    
+
     ep = EpisodeInfo(
         seriesname = 'Star Trek TNG',
         seasonnumber = 1,
