@@ -3,7 +3,6 @@
 """Constructs command line argument parser for tvnamer
 """
 
-from __future__ import with_statement
 import sys
 import optparse
 
@@ -27,21 +26,13 @@ class Group(object):
 def getCommandlineParser(defaults):
     parser = optparse.OptionParser(usage = "%prog [options] <files>", add_help_option = False)
 
-    if sys.version_info < (2, 6, 5):
-        # Hacky workaround to avoid bug in Python 2.6.1 triggered by use of builtin json module in 2.6
-        # http://bugs.python.org/issue4978
-        # http://bugs.python.org/issue2646
-
-        #TODO: Remove this at some point
-        defaults = dict([(str(k), v) for k, v in defaults.items()])
-
     parser.set_defaults(**defaults)
 
     # Console output
     with Group(parser, "Console output") as g:
         g.add_option("-v", "--verbose", action="store_true", dest="verbose", help = "show debugging info")
         g.add_option("-q", "--not-verbose", action="store_false", dest="verbose", help = "no verbose output (useful to override 'verbose':true in config file)")
-
+        g.add_option("--dry-run", action="store_true", dest="dry_run", help = "Only tell what script is going to do")
 
     # Batch options
     with Group(parser, "Batch options") as g:
@@ -54,7 +45,6 @@ def getCommandlineParser(defaults):
         g.add_option("-b", "--batch", action="store_true", dest = "batch", help = "Rename without human intervention, same as --always and --selectfirst combined")
         g.add_option("--not-batch", action="store_false", dest = "batch", help = "Overrides --batch")
 
-
     # Config options
     with Group(parser, "Config options") as g:
         g.add_option("-c", "--config", action = "store", dest = "loadconfig", help = "Load config from this file")
@@ -65,6 +55,7 @@ def getCommandlineParser(defaults):
     with Group(parser, "Override values") as g:
         g.add_option("-n", "--name", action="store", dest = "force_name", help = "override the parsed series name with this (applies to all files)")
         g.add_option("--series-id", action="store", dest = "series_id", help = "explicitly set the show id for TVdb to use (applies to all files)")
+        g.add_option("--order", action = "store", dest = "order", help = "set the TvDB episode order ('aired' [default] or 'dvd')")
 
     # Misc
     with Group(parser, "Misc") as g:
@@ -74,18 +65,12 @@ def getCommandlineParser(defaults):
         g.add_option("-m", "--move", action="store_true", dest="move_files_enable", help = "Move files to destination specified in config or with --movedestination argument")
         g.add_option("--not-move", action="store_false", dest="move_files_enable", help = "Files will remain in current directory")
 
+        g.add_option("--force-move", action="store_true", dest = "overwrite_destination_on_move", help = "Force move and potentially overwrite existing files in destination folder")
+        g.add_option("--force-rename", action="store_true", dest = "overwrite_destination_on_rename", help = "Force rename source file")
+        
         g.add_option("-d", "--movedestination", action="store", dest = "move_files_destination", help = "Destination to move files to. Variables: %(seriesname)s %(seasonnumber)d %(episodenumbers)s")
 
         g.add_option("-h", "--help", action="help", help = "show this help message and exit")
 
 
     return parser
-
-
-if __name__ == '__main__':
-
-    def main():
-        p = getCommandlineParser({'recursive': True})
-        print p.parse_args()
-
-    main()
