@@ -16,6 +16,10 @@ defaults = {
     # Fail if error finding show data (thetvdb.com is down etc)
     # Only functions when always_rename is True
     'skip_file_on_error': True,
+    
+    # Fail if error finding show data (thetvdb.com is down etc)
+    # Changes the default behaviour for skip_file_on_error from skip to exit
+    'skip_behaviour': 'skip',
 
     # Forcefully overwrite existing files when renaming or
     # moving. This potentially destroys the old file. Default is False
@@ -25,6 +29,9 @@ defaults = {
     # Verbose mode (debugging info)
     'verbose': False,
 
+    # Dry-run mode (do nothing)
+    'dry_run': False,
+
     # Recurse more than one level into folders. When False, only
     # desends one level.
     'recursive': False,
@@ -450,4 +457,7 @@ defaults = {
     # since these are perfectly predictable, they are simple strings
     # not regular expressions
     'output_series_replacements': {},
+
+    # use dvd episode order of tvdb, instead of aired order
+    'order': 'aired',
 }
