@@ -13,10 +13,7 @@ try:
 except ImportError:
     pass
 
-try:
-    import json
-except ImportError:
-    import simplejson as json
+import json
 
 from tvdb_api import Tvdb
 
@@ -30,16 +27,10 @@ applyCustomInputReplacements, formatEpisodeNumbers, makeValidFilename,
 DatedEpisodeInfo, NoSeasonEpisodeInfo)
 
 from tvnamer.tvnamer_exceptions import (ShowNotFound, SeasonNotFound, EpisodeNotFound,
-EpisodeNameNotFound, UserAbort, InvalidPath, NoValidFilesFoundError,
+EpisodeNameNotFound, UserAbort, InvalidPath, NoValidFilesFoundError, SkipBehaviourAbort,
 InvalidFilename, DataRetrievalError)
 
 
-def log():
-    """Returns the logger for current file
-    """
-    return logging.getLogger(__name__)
-
-
 def getMoveDestination(episode):
     """Constructs the location to move/copy the file
     """
@@ -91,7 +82,10 @@ def doRenameFile(cnamer, newName):
     try:
         cnamer.newPath(new_fullpath = newName, force = Config['overwrite_destination_on_rename'], leave_symlink = Config['leave_symlink'])
     except OSError as e:
-        warn(e)
+        if Config['skip_behaviour'] == 'exit':
+            warn("Exiting due to error: %s" % e)
+            raise SkipBehaviourAbort()
+        warn("Skipping file due to error: %s" % e)
 
 
 def doMoveFile(cnamer, destDir = None, destFilepath = None, getPathPreview = False):
@@ -117,7 +111,10 @@ def doMoveFile(cnamer, destDir = None, destFilepath = None, getPathPreview = Fal
             force = Config['overwrite_destination_on_move'])
 
     except OSError as e:
-        warn(e)
+        if Config['skip_behaviour'] == 'exit':
+            warn("Exiting due to error: %s" % e)
+            raise SkipBehaviourAbort()
+        warn("Skipping file due to error: %s" % e)
 
 
 def confirm(question, options, default = "y"):
@@ -170,6 +167,9 @@ def processFile(tvdb_instance, episode):
         episode.populateFromTvdb(tvdb_instance, force_name=Config['force_name'], series_id=Config['series_id'])
     except (DataRetrievalError, ShowNotFound) as errormsg:
         if Config['always_rename'] and Config['skip_file_on_error'] is True:
+            if Config['skip_behaviour'] == 'exit':
+                warn("Exiting due to error: %s" % errormsg)
+                raise SkipBehaviourAbort()
             warn("Skipping file due to error: %s" % errormsg)
             return
         else:
@@ -177,6 +177,9 @@ def processFile(tvdb_instance, episode):
     except (SeasonNotFound, EpisodeNotFound, EpisodeNameNotFound) as errormsg:
         # Show was found, so use corrected series name
         if Config['always_rename'] and Config['skip_file_on_error']:
+            if Config['skip_behaviour'] == 'exit':
+                warn("Exiting due to error: %s" % errormsg)
+                raise SkipBehaviourAbort()
             warn("Skipping file due to error: %s" % errormsg)
             return
 
@@ -220,6 +223,12 @@ def processFile(tvdb_instance, episode):
                         doMoveFile(cnamer = cnamer, destDir = getMoveDestination(episode))
                 return
 
+            elif Config['dry_run']:
+                p("%s will be renamed to %s" % (episode.fullfilename, newName))
+                if Config['move_files_enable']:
+                    p("%s will be moved to %s" % (newName, getMoveDestination(episode)))
+                return
+
             ans = confirm("Rename?", options = ['y', 'n', 'a', 'q'], default = 'y')
 
             if ans == "a":
@@ -242,6 +251,10 @@ def processFile(tvdb_instance, episode):
 
     if shouldRename and Config['move_files_enable']:
         newPath = getMoveDestination(episode)
+        if Config['dry_run']:
+            p("%s will be moved to %s" % (newName, getMoveDestination(episode)))
+            return
+
         if Config['move_files_destination_is_filepath']:
             doMoveFile(cnamer = cnamer, destFilepath = newPath, getPathPreview = True)
         else:
@@ -438,6 +451,8 @@ def main():
         opter.error("No valid files were supplied")
     except UserAbort as errormsg:
         opter.error(errormsg)
+    except SkipBehaviourAbort as errormsg:
+        opter.error(errormsg)
 
 if __name__ == '__main__':
     main()
