@@ -534,6 +534,7 @@ def makeValidFilename(value, normalize_unicode = False, windows_safe = False, cu
         import unicodedata
         value = string_type(value) # cast data to unicode
         value = unicodedata.normalize('NFKD', value).encode('ascii', 'ignore')
+        value = value.decode('utf-8')
 
     # Truncate filenames to valid/sane length.
     # NTFS is limited to 255 characters, HFS+ and EXT3 don't seem to have
@@ -659,6 +660,10 @@ class EpisodeInfo(object):
             for cepno in self.episodenumbers:
                 try:
                     sr = show.airedOn(cepno)
+                    if len(sr) > 1:
+                        # filter out specials if multiple episodes aired on the day
+                        sr = [ s for s in sr if s['seasonnumber'] != '0' ]
+                    
                     if len(sr) > 1:
                         raise EpisodeNotFound(
                             "Ambigious air date %s, there were %s episodes on that day" % (
@@ -689,13 +694,13 @@ class EpisodeInfo(object):
                     self.seriesname))
 
             except tvdb_episodenotfound:
-                # Try to search by absolute_number
-                sr = show.search(cepno, "absolute_number")
+                # Try to search by absolute number
+                sr = show.search(cepno, "absoluteNumber")
                 if len(sr) > 1:
                     # For multiple results try and make sure there is a direct match
                     unsure = True
                     for e in sr:
-                        if int(e['absolute_number']) == cepno:
+                        if int(e['absoluteNumber']) == cepno:
                             epnames.append(e['episodename'])
                             unsure = False
                     # If unsure error out
